@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 
-''' Copyright 2013 Smartling, Inc.
+""" Copyright 2012-2021 Smartling, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this work except in compliance with the License.
@@ -15,7 +15,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
-'''
+"""
 
 import os
 import sys
@@ -64,5 +64,5 @@ class test_SmartlingDirective(object):
         apiV2.clientUid = "test_test"
         params = {}
         apiV2.addLibIdDirective(params)
-        assert_equal(True, SmartlingDirective.sl_prefix + 'client_lib_id' in params)
-        assert_equal(params[SmartlingDirective.sl_prefix + 'client_lib_id'], "test_test")
+        assert_equal(True, SmartlingDirective.SL_PREFIX + 'client_lib_id' in params)
+        assert_equal(params[SmartlingDirective.SL_PREFIX + 'client_lib_id'], "test_test")
